import { describe, it, expect, afterEach } from '@jest/globals'
import { build, createServer } from 'vite'
import rollupPluginPo2Json from '@open-xchange/rollup-plugin-po2json'

import vitePluginOxManifests from '../../dist/index'
import { getFileFromBundle, getPort, getDirname } from '../util'

const PORT = getPort()
const __dirname = getDirname(import.meta.url)

describe('Simple gettext scenario', function () {
  let server

  afterEach(async function () {
    if (server) {
      await server.close()
      server = null
    }
  })

  it('works', async function () {
    const bundle = await build({
      root: __dirname,
      logLevel: 'silent',
      build: { write: false, rollupOptions: { input: {}, cache: true } },
      plugins: [rollupPluginPo2Json({
        poFiles: __dirname + '/i18n/*.po'
      }), vitePluginOxManifests({

      })]
    })

    const manifestFile = getFileFromBundle('manifest', bundle)
    const manifests = JSON.parse(manifestFile.source)
    expect(Object.keys(manifests)).toHaveLength(5)
    expect(manifests['register.js'].meta.manifests[0].namespace).toEqual('test')
    expect(manifests['../../i18n.js'].meta.manifests[0].namespace).toEqual('i18n')
  })

  it('works in dev mode', async function () {
    server = await createServer({
      root: __dirname,
      logLevel: 'silent',
      plugins: [rollupPluginPo2Json({
        poFiles: __dirname + '/i18n/*.po'
      }), vitePluginOxManifests({

      })]
    })
    await server.listen(PORT)

    const res = await fetch(`http://localhost:${PORT}/api/manifest.json`)
    const manifests = await res.json()

    expect(manifests).toHaveLength(2)
    expect(manifests[0].namespace).toEqual('i18n')
    expect(manifests[0].path).toContain('i18n')
    expect(manifests[1].namespace).toEqual('test')
    expect(manifests[1].path).toContain('register')
  })
})
