import path from 'node:path'
import { describe, it, expect } from '@jest/globals'
import { build } from 'vite'

import { getFileFromBundle, getDirname } from '../util'

const __dirname = getDirname(import.meta.url)

describe('HTML relative paths', function () {
  it('transforms paths', async function () {
    // keep this test here as reference. Transformation is now done via vite itself
    const bundle = await build({
      root: __dirname,
      logLevel: 'silent',
      base: './',
      build: {
        write: false,
        rollupOptions: {
          input: {
            'index.html': path.join(__dirname, 'index.html'),
            'other.html': path.join(__dirname, 'other.html')
          }
        }
      }
    })

    const indexFile = getFileFromBundle('index.html', bundle)
    expect(indexFile.source).toContain('src="./')
    expect(indexFile.source).toContain('href="./')
    expect(indexFile.source).not.toContain('src="/')
    expect(indexFile.source).not.toContain('href="/')

    const otherFile = getFileFromBundle('other.html', bundle)
    expect(otherFile.source).toContain('src="./')
    expect(otherFile.source).toContain('href="./')
    expect(otherFile.source).not.toContain('src="/')
    expect(otherFile.source).not.toContain('href="/')
  })
})
